.. _version_history:


Version History
===============

.. csv-table::
   :header: "Release", "Details"
   :widths: 20, 100

   "0.1.0", "updates for django 3; code cleanup"
   "0.0.6", "adding support for user_logged_in/user_login_failed/user_logged_out signals"
   "0.0.5", "fixed bug causing OperationalError on migrate"
   "0.0.4", "project structure updates"
   "0.0.3", "bug fixes and code cleanup"
   "0.0.2", "added documentation"
   "0.0.1", "initial release"


Source Code
-----------

Source code for django-signalcontrol is available on github: https://github.com/davidslusser/django-signalcontrol/
